aboutsummaryrefslogtreecommitdiff
path: root/src/lua/modules/math
diff options
context:
space:
mode:
authorchai <chaifix@163.com>2018-10-20 16:18:11 +0800
committerchai <chaifix@163.com>2018-10-20 16:18:11 +0800
commitcf68d9f46da1cf20503a7d738da1f43de916004d (patch)
tree5577e44d926deadb15ef5ca145e705eae14636fe /src/lua/modules/math
parente9410bd371fc68169c57d2c52382948a0b083da4 (diff)
*格式化代码
Diffstat (limited to 'src/lua/modules/math')
-rw-r--r--src/lua/modules/math/math.cpp44
1 files changed, 22 insertions, 22 deletions
diff --git a/src/lua/modules/math/math.cpp b/src/lua/modules/math/math.cpp
index dafec72..fe05b3e 100644
--- a/src/lua/modules/math/math.cpp
+++ b/src/lua/modules/math/math.cpp
@@ -1,30 +1,30 @@
#include "lua/modules/luax.h"
#include "libjin/jin.h"
-namespace jin
+namespace JinEngine
{
-namespace lua
-{
-
- static int l_mod(lua_State* L)
+ namespace Lua
{
- int n = luax_checkinteger(L, 1);
- int m = luax_checkinteger(L, 2);
- int mod = n % m;
- luax_pushinteger(L, mod);
- return 1;
- }
- static const luaL_Reg f[] = {
- { "mod", l_mod },
- { 0, 0 }
- };
+ static int l_mod(lua_State* L)
+ {
+ int n = luax_checkinteger(L, 1);
+ int m = luax_checkinteger(L, 2);
+ int mod = n % m;
+ luax_pushinteger(L, mod);
+ return 1;
+ }
- int luaopen_math(lua_State* L)
- {
- luax_newlib(L, f);
- return 1;
- }
+ static const luaL_Reg f[] = {
+ { "mod", l_mod },
+ { 0, 0 }
+ };
+
+ int luaopen_math(lua_State* L)
+ {
+ luax_newlib(L, f);
+ return 1;
+ }
-} // lua
-} // jin \ No newline at end of file
+ } // Lua
+} // JinEngine \ No newline at end of file